<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://www.teowin.nl
 * @since      1.0.0
 *
 * @package    twjtable
 * @subpackage twjtable/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    twjtable
 * @subpackage twjtable/public
 * @author     Teo Super plugins@teowin.nl
 */



class twjtable_Public {

	private $plugin_name;

	private $version;

	private $database;

	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	public function register_shortcodes(){
		add_shortcode( 'twjtable', array( $this, 'twjtable_shortcode') );
	}

	public function twjtable_shortcode($atts, $content = null) {

		//set default attributes and values
		$values = shortcode_atts( array(
			'formid'   	=> '-1',
			'lines'     => 5,
			'columnwidths' => "",
		), $atts );

		$columnwidths = json_decode( $values['columnwidths'], true );
		if( !is_array( $columnwidths ) or count( $columnwidths )<1 ) $columnwidths = array();

		$formid = esc_attr($values['formid']);
        $records = esc_attr($values['lines']);

		$dbObj = new twjtable_Database( $this->plugin_name, $this->version ) ;

		$protocol = isset($_SERVER['HTTPS']) && strcasecmp('off', $_SERVER['HTTPS']) !== 0 ? "https" : "http";
		$hostname = $_SERVER['HTTP_HOST'];

		$listurl = "{$protocol}://{$hostname}/wp-admin/admin-ajax.php";
        $fieldscript = '';
        $formname = '';


        $editing = TRUE;  /* Since 1.1 */

		$test = $dbObj::getformfields($formid, $listurl, $fieldscript, $formname, $columnwidths, $editing);

$output = <<<OUTPUT
<div id="jsGrid" style="width:100%;"></div>
<script>
$(function() {
    $("#jsGrid").jsGrid({
        width: "100%",
        inserting: true,
        editing: $editing,
        paging: true,
        autoload: true,
       
	    noDataContent: "Not found",
	    updateOnResize: true,
	    confirmDeleting: true,
	    deleteConfirm: "Are you sure?",
	    pageLoading: true,
	  //  pageIndex: 1,
	    pageSize: $records,
	    pageButtonCount: 5,
	    pagerFormat: "Pages: {first} {prev} {pages} {next} {last}    {pageIndex} from {pageCount}",
	    pagePrevText: "Prev",
	    pageNextText: "Next",
	    pageFirstText: "First",
	    pageLastText: "Last",
	    pageNavigatorNextText: "...",
	    pageNavigatorPrevText: "...",
         controller: {
             loadData: function(filter){
		    	    var deferred = $.Deferred();
			         $.ajax({
			            type: "post",
			            url: "$listurl?action=list_entries&formid=$formid",
			            data: filter,
			            dataType:"json",
			            success:function(datas){
			        	  var da = {
			        		data :datas.Records,
			        		itemsCount : datas.TotalRecordCount
			        	  };
			        	 
			        	  deferred.resolve(da);
			        }
			        });
			        return deferred.promise();
		    },
               
                insertItem: function(item) {
                    return $.ajax({
                        type: "POST",
                        dataType: "json",
                         url: "$listurl?action=create_entry&formid=$formid",
                        data: item
                    });
                },

			          
				updateItem: function(updatingItem) { 
		                var d = $.Deferred();
		                $.ajax({
		                    type: "POST",
		                     url: "$listurl?action=update_entry&formid=$formid",
		                    data: updatingItem
		                }).done(function(response) {
		                    d.resolve(response.data);
		                }).fail(function() {
		                    d.resolve(previousItem);
		                });
		
		                return d.promise();
		        },        
                deleteItem: function(item) {
			        var d = $.Deferred();
			        $.ajax({
			            url: "$listurl?action=delete_entry&formid=$formid",
			            type: "POST",
			            data: item
			        }).done(function(deletedItem) {
			            d.resolve();
			        });
			        return d.promise();
			    }
			 },

        fields: 
            $fieldscript
        
              
    });
    
    });

</script>
OUTPUT;

           return $output;
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

	//	wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/wppb-demo-plugin-public.css', array(), $this->version, 'all' );
		wp_enqueue_style( 'jsgridmin', plugin_dir_url( __FILE__ ) . 'jsGrid/css/jsgrid.min.css', array(), $this->version, 'all' );
		wp_enqueue_style( "jsgridtheme", plugin_dir_url( __FILE__ ) . 'jsGrid/css/jsgrid-theme.min.css', array(), $this->version, 'all');

	//	wp_enqueue_style( "jtable_jqueryui", plugin_dir_url( __FILE__ ) . 'jtable/themes/jqueryui/jtable_jqueryui.css', array(), $this->version, 'all');

	}

	public function enqueue_scripts(){
		wp_enqueue_script( 'jquery_min', plugin_dir_url( __FILE__ ). 'js/jquery-3.3.1.min.js', $this->version, false );
		wp_enqueue_script( 'jquery_ui', plugin_dir_url( __FILE__ ). 'js/jquery-ui.min.js', $this->version, false );
		wp_enqueue_script( 'colresize', plugin_dir_url( __FILE__ ). 'js/colResizable-1.6.js', $this->version, false );
		wp_enqueue_script( 'jGrid', plugin_dir_url( __FILE__ ) . 'jsGrid/jsgrid.min.js', $this->version, false );
	}

	public function enqueue_styles2() {

		//	wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/wppb-demo-plugin-public.css', array(), $this->version, 'all' );
		wp_enqueue_style( 'jqueryuicss', plugin_dir_url( __FILE__ ) . 'css/jquery-ui.css', array(), $this->version, 'all' );
		wp_enqueue_style( "jtable_basic", plugin_dir_url( __FILE__ ) . 'jtable/themes/basic/jtable_basic.css', array(), $this->version, 'all');

		wp_enqueue_style( "jqueryui", plugin_dir_url( __FILE__ ) . 'jtable/themes/metro/blue/jtable.css', array(), $this->version, 'all');
		wp_enqueue_style( "jtable_jqueryui", plugin_dir_url( __FILE__ ) . 'jtable/themes/jqueryui/jtable_jqueryui.css', array(), $this->version, 'all');

	}

}
